# coding: utf-8
#
# BMPC Music Player Client
#
# Copyright (C) 2015 Itaï BEN YAACOV
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.


from gi.repository import Gtk, Gdk

import ampd

from .utils import actions
from .utils import omenu


class Component(object):
    title = None
    name = None
    key = None
    action_prefix = 'comp'

    def __init__(self, shared):
        super(Component, self).__init__()
        self.shared = shared
        self.config = self.shared.config.setdefault(self.name, {})
        self.ampd_worker_group = ampd.WorkerGroup(self.shared.ampd_client)
        self.ampd_worker_group.connect_loop(self.connect_cb, self.disconnect_cb)
        self.actions = actions.SimpleActionGroup()
        self.signals = {}
        self.win = None

    def close(self):
        if self.win:
            self.win.destroy()
        self.ampd_worker_group.close()
        self.widget.destroy()
        self.actions.clear_actions()
        del self.signals

    def start(self, win):
        self.win = win
        win.insert_action_group(self.action_prefix, self.actions)
        for name, cb in self.signals.items():
            win.connect(name, cb)

    def stop(self):
        self.win.label_component.set_visible(False)
        self.win.insert_action_group(self.action_prefix, None)
        for cb in self.signals.values():
            self.win.disconnect_by_func(cb)
        self.win = None

    @staticmethod
    def restart():
        pass

    def setup_context_menu(self, paths, widget):
        context_menu = omenu.OrderedMenu()
        for path in paths:
            context_menu.insert_path(*path)
        gtk_context_menu = Gtk.Menu.new_from_model(context_menu)
        gtk_context_menu.insert_action_group(self.action_prefix, self.actions)
        widget.connect('button-press-event', self.context_menu_button_press_event_cb, gtk_context_menu)

    @staticmethod
    def context_menu_button_press_event_cb(widget, event, context_menu):
        if event.type == Gdk.EventType.BUTTON_PRESS and event.button == 3:
            context_menu.popup(None, None, None, None, event.button, event.time)
            return True

    connect_cb = disconnect_cb = None
