# coding: utf-8
#
# BMPC Music Player Client
#
# Copyright (C) 2015 Itaï BEN YAACOV
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.


from gi.repository import GObject, Gdk

from bmpc import component


class Current(component.Component):
    title = _('Current Song')
    name = 'current'
    key = '0'

    fields = ['title', 'artist', 'performer', 'date', 'genre', 'composer']

    def __init__(self, *args):
        super(Current, self).__init__(*args)
        builder = self.shared.build_ui('plugins/current')
        for field in self.fields:
            label = builder.get_object('label_' + field)
            self.shared.bind_property('current-song', label, 'label', GObject.BindingFlags.SYNC_CREATE, lambda x, y, z: y.get(z), None, field)
            self.shared.bind_property('current-song', label, 'visible', GObject.BindingFlags.SYNC_CREATE, lambda x, y, z: z in y, None, field)
        self.shared.bind_property('state', builder.get_object('welcome'), 'visible', GObject.BindingFlags.SYNC_CREATE, lambda x, y: y == 'stop')
        self.shared.bind_property('state', builder.get_object('current'), 'visible', GObject.BindingFlags.SYNC_CREATE, lambda x, y: y != 'stop')
        self.widget = builder.get_object('widget')
        self.widget.connect('button-press-event', self.button_press_event_cb)

    def button_press_event_cb(self, widget, event):
        if event.type == Gdk.EventType.DOUBLE_BUTTON_PRESS and event.button == 1:
            self.win.action_toggle_fullscreen_cb()


__components__ = [Current]
