# coding: utf-8
#
# BMPC Music Player Client
#
# Copyright (C) 2015 Itaï BEN YAACOV
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.


from gi.repository import Gtk

import ampd

from . import songlist


class Search(songlist.SongList):
    title = _('Search')
    name = 'search'
    key = '3'

    sortable = True

    def __init__(self, *args, **kwargs):
        super(Search, self).__init__(*args, **kwargs)

        self.entry = Gtk.SearchEntry(visible=True)
        self.entry.connect('activate', self.entry_activate_cb)
        self.field_choice = Gtk.ComboBoxText(visible=True)
        self.field_choice.append_text(_('any field'))
        for name in self.fields.names:
            self.field_choice.append_text(name)
        self.field_choice.set_active(0)
        bottom_box = Gtk.Box(orientation=Gtk.Orientation.HORIZONTAL, visible=True)
        bottom_box.pack_start(self.field_choice, False, False, 0)
        bottom_box.pack_end(self.entry, True, True, 0)
        box = Gtk.Box(orientation=Gtk.Orientation.VERTICAL, visible=True)
        box.add(self.widget)
        box.add(bottom_box)
        self.widget = box

        self.actions.add_complex_action('search', self.restart)

    def start(self, win):
        self.entry.grab_focus()
        super(Search, self).start(win)

    def restart(self, *args):
        self.entry.grab_focus()

    @ampd.worker
    def connect_cb(self):
        while True:
            self.entry_activate_cb()
            yield ampd.DATABASE

    def action_reset_cb(self, action, parameter):
        self.field_choice.set_active(0)
        self.store.set_sort_column_id(-1, Gtk.SortType.ASCENDING)
        self.entry_activate_cb()

    @ampd.worker
    def entry_activate_cb(self, *args):
        text = self.entry.get_text().split()
        if not text:
            return
        field = 'any' if self.field_choice.get_active() == 0 else self.field_choice.get_active_text()
        songs = yield ampd.search(*sum(([field, value] for value in text), []))
        self.set_songs(songs)


__components__ = [Search]
__depends__ = ['songlist']
__menubar_paths__ = [('20#edit/10#global/30', 'comp.search', _('Search'), ['<Control>f'])]
