# coding: utf-8
#
# BMPC Music Player Client
#
# Copyright (C) 2015 Itaï BEN YAACOV
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.


from gi.repository import GObject, Gio, GLib


class ActionGroup(object):
    def add_complex_action(self, name, activate_cb=None, parameter_type=None, state=None, unsafe=False, is_flag=False, shared=None, data=()):
        if is_flag and state == None:
            state = GLib.Variant.new_boolean(False)
        if state == None:
            action = Gio.SimpleAction.new(name, parameter_type)
        else:
            action = Gio.SimpleAction.new_stateful(name, parameter_type, state)
        action.activate_handler = action.connect('activate', activate_cb, *data) if activate_cb else None
        if unsafe:
            shared.bind_property('safe-mode', action, 'enabled', GObject.BindingFlags.SYNC_CREATE, lambda x, y: not y)
        if is_flag:
            shared.bind_property(name, action, 'state', GObject.BindingFlags.SYNC_CREATE | GObject.BindingFlags.BIDIRECTIONAL, lambda x, y: GLib.Variant.new_boolean(y), lambda x, y: y.get_boolean())
        self.add_action(action)

    def clear_actions(self):
        for name in self.list_actions():
            action = self.lookup_action(name)
            if action.activate_handler:
                action.disconnect(action.activate_handler)
            self.remove_action(name)


class SimpleActionGroup(Gio.SimpleActionGroup, ActionGroup):
    pass
